ASK: Adaptive Sampling Kit
==========================

Adaptive Sampling Kit (ASK) is a toolkit for sampling big experimental spaces. It features multiple active learning algorithms 
to prioritize the exploration of the interesting parts of the experimental space. 

Documentation
=============

ASK user manual is available at the following URL
 
https://github.com/benchmark-subsetting/adaptive-sampling-kit/wiki/Chapter-1:-Introduction

Licence
=======

Copyright (c) 2011-2015, Université de Versailles St-Quentin-en-Yvelines and Contributors
ASK is released under the GNU General Public License, version 2. Please refer to LICENSE, for details.

Contact
=======

For any question regarding ASK, please write to the adaptive sampling kit mailing list at 
[adaptive-sampling-kit@googlegroups.com](mailto:adaptive-sampling-kit@googlegroups.com).

For bug reports, features requests or contributions please use the [project
tracker](https://github.com/benchmark-subsetting/adaptive-sampling-kit).

